const textarea = document.querySelector("main textarea");
const outputElement = document.querySelector("#output");

const DEBOUNCE_DURATION = 150; // ms

// Load from local storage if present
const savedInput = localStorage.getItem("input");
if (savedInput) {
  textarea.value = savedInput;
}

let timeoutId;

const fileNameFromTitle = (title) =>
  (title ?? "untitled")
    .toLowerCase()
    .replace(/ /g, "-")
    .replace(/[():;,.?!]/g, "");

if (window.Worker) {
  const cacheBuster = new Date().toLocaleString().replace(" ", "");
  const worker = new Worker(`worker.js?${cacheBuster}`);

  // On load
  worker.postMessage(textarea.value);

  window.addEventListener("input", (e) => {
    clearTimeout(timeoutId);

    timeoutId = setTimeout(() => {
      worker.postMessage(textarea.value);
      localStorage.setItem("input", textarea.value);
    }, DEBOUNCE_DURATION);
  });

  worker.onmessage = (e) => {
    const { title, output } = e.data;

    outputElement.innerHTML = output;
    document.title = fileNameFromTitle(title);
  };
} else {
  console.error("Your browser doesn't support web workers.");
  // TODO: show a visible message
}
